@@ -46,133 +46,79 @@ require_once($cgextensions);
 
 class Postcode extends CGExtensions
 {
-  /*---------------------------------------------------------
-   GetName()
-   ---------------------------------------------------------*/
   function GetName()
   {
     return 'Postcode';
   }
 
-  /*---------------------------------------------------------
-   GetFriendlyName()
-   ---------------------------------------------------------*/
   function GetFriendlyName()
   {
     return $this->Lang('friendlyname');
   }
-
 	
-  /*---------------------------------------------------------
-   GetVersion()
-   ---------------------------------------------------------*/
   function GetVersion()
   {
-    return '1.1.1';
+    return '1.2.1';
   }
 
-
-  /*---------------------------------------------------------
-   GetHelp()
-   ---------------------------------------------------------*/
   function GetHelp()
   {
-    return $this->Lang('help');
+    return file_get_contents(dirname(__FILE__).'/help.inc');
   }
 
+  public function LazyLoadAdmin() { return TRUE; }
+  public function LazyLoadFrontend() { return TRUE; }
 
-  /*---------------------------------------------------------
-   GetAuthor()
-   ---------------------------------------------------------*/
   function GetAuthor()
   {
     return 'calguy1000';
   }
 
-
-  /*---------------------------------------------------------
-   GetAuthorEmail()
-   ---------------------------------------------------------*/
   function GetAuthorEmail()
   {
     return 'calguy1000@cmsmadesimple.org';
   }
 
-
-  /*---------------------------------------------------------
-   GetChangeLog()
-   ---------------------------------------------------------*/
   function GetChangeLog()
   {
     return $this->Lang('changelog');
   }
   
-  /*---------------------------------------------------------
-   IsPluginModule()
-   ---------------------------------------------------------*/
   function IsPluginModule()
   {
     return true;
   }
 
-
-  /*---------------------------------------------------------
-   HasAdmin()
-   ---------------------------------------------------------*/
   function HasAdmin()
   {
     return true;
   }
 
-
-  /*---------------------------------------------------------
-   GetAdminSection()
-   ---------------------------------------------------------*/
   function GetAdminSection()
   {
     return 'extensions';
   }
 
-
-  /*---------------------------------------------------------
-   GetAdminDescription()
-   ---------------------------------------------------------*/
   function GetAdminDescription()
   {
     return $this->Lang('moddescription');
   }
 
-
-  /*---------------------------------------------------------
-   VisibleToAdminUser()
-   ---------------------------------------------------------*/
   function VisibleToAdminUser()
   {
     return $this->CheckPermission('Modify Site Preferences');
   }
 
-
-  /*---------------------------------------------------------
-   GetDependencies()
-   ---------------------------------------------------------*/
   function GetDependencies()
   {
-    return array('CGExtensions'=>'1.19.4');
+    return array('CGExtensions'=>'1.31');
   }
 
-
-  /*---------------------------------------------------------
-   MinimumCMSVersion()
-   ---------------------------------------------------------*/
   function MinimumCMSVersion()
   {
-    return "1.8.1";
+    return "1.11.2";
   }
 	
-	
-  /*---------------------------------------------------------
-   SetParameters()
-   ---------------------------------------------------------*/
   function SetParameters()
   {
     $this->RestrictUnknownParams();
@@ -181,42 +127,24 @@ class Postcode extends CGExtensions
     $this->SetParameterType('prev',CLEAN_STRING);
   }
 
-
-  /*---------------------------------------------------------
-   InstallPostMessage()
-   ---------------------------------------------------------*/
   function InstallPostMessage()
   {
     return $this->Lang('postinstall');
   }
 
-
-  /*---------------------------------------------------------
-   UninstallPostMessage()
-   ---------------------------------------------------------*/
   function UninstallPostMessage()
   {
     return $this->Lang('postuninstall');
   }
 
-
-  /*---------------------------------------------------------
-   UninstallPreMessage()
-   ---------------------------------------------------------*/
   function UninstallPreMessage()
   {
     return $this->Lang('really_uninstall');
   }	
 
-
-  /*---------------------------------------------------------
-   private
-   _db_lookup_zip($country,$postal)
-   ---------------------------------------------------------*/
-  function _db_lookup_zip($country,$postal)
+  protected function _db_lookup_zip($country,$postal)
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
 
     $query = 'SELECT * FROM '.cms_db_prefix().'module_postcode
                      WHERE country = ? AND postal = ?';
@@ -226,15 +154,12 @@ class Postcode extends CGExtensions
     return $row;
   }
 
-  
-  /*---------------------------------------------------------
-   private
-   _online_lookup_zip($country,$postal)
-   ---------------------------------------------------------*/
-  function _online_lookup_zip($country,$postal)
+  protected function _online_lookup_zip($country,$postal)
   {
-    $post_url = 'http://ws.geonames.org/postalCodeSearchJSON';
-    $post_string = "country={$country}&postalcode_startsWith={$postal}&maxRows=1";
+    $post_url = 'http://api.geonames.org/postalCodeSearchJSON';
+    $username = $this->GetPreference('geonames_username');
+    if( !$username ) return FALSE;
+    $post_string = "username={$username}&country={$country}&postalcode_startsWith={$postal}&maxRows=1";
     $request = curl_init($post_url); // initiate curl object
     curl_setopt($request, CURLOPT_HEADER, 0); // set to 0 to eliminate header info from response
     curl_setopt($request, CURLOPT_RETURNTRANSFER, 1); // Returns response data instead of TRUE(1)
@@ -244,10 +169,14 @@ class Postcode extends CGExtensions
     curl_close ($request); // close curl object
 
     $json = json_decode($post_response,true);
-    if( !is_array($json) || !is_array($json['postalCodes']) || !count($json['postalCodes']) )
-      {
-	return FALSE;
+    if( !is_array($json) || !is_array($json['postalCodes']) || !count($json['postalCodes']) ) {
+      $msg = 'Unknown error occurred';
+      if( is_array($json) && isset($json['status']) && isset($json['status']['message']) ) {
+	$msg = 'ERROR: '.$json['status']['message'];
       }
+      audit('',$this->GetName(),$msg);
+      return FALSE;
+    }
     $data = array('country'=>$json['postalCodes'][0]['countryCode'],
 		  'postal'=>$json['postalCodes'][0]['postalCode'],
 		  'state'=>$json['postalCodes'][0]['adminCode1'],
@@ -258,15 +187,9 @@ class Postcode extends CGExtensions
     return $data;
   }
 
-
-  /*---------------------------------------------------------
-   private
-   _store_zip($data)
-   ---------------------------------------------------------*/
-  function _store_zip($data)
+  protected function _store_zip($data)
   {
-    global $gCms;
-    $db =& $gCms->GetDb();
+    $db = cmsms()->GetDb();
 
     $query = 'INSERT INTO '.cms_db_prefix().'module_postcode (country,postal,place,state,latitude,longitude)
                VALUES (?,?,?,?,?,?)';
@@ -279,69 +202,49 @@ class Postcode extends CGExtensions
 	return FALSE;
       }
     return TRUE;
-  }
-  
+  }  
 
-  /*---------------------------------------------------------
-   public
-   Lookup_Zip($country,$postal)
-   ---------------------------------------------------------*/
-  function Lookup_Zip($country,$postal,$echars = '')
+  public function Lookup_Zip($country,$postal,$echars = '')
   {
-    if( empty($country) || empty($postal) )
-      {
-	return FALSE;
-      }
+    if( empty($country) || empty($postal) ) {
+      return FALSE;
+    }
 
-    if( $effective_chars == '' || !is_numeric($echars) )
-      {
-	$echars = (int)$this->GetPreference('effective_chars');
-      }
-    if( $echars > 0 )
-      {
-	$postal = substr($postal,0,$echars);
-      }
+    if( $echars == '' || !is_numeric($echars) ) {
+      $echars = (int)$this->GetPreference('effective_chars');
+    }
+    if( $echars > 0 ) {
+      $postal = substr($postal,0,$echars);
+    }
 
     $opmode = $this->GetPreference('operation_mode',0);
     $data = '';
-    switch( $opmode )
-      {
-      case 1: // dbonly
-	{
-	  $data = $this->_db_lookup_zip($country,$postal);
-	}
-	break;
+    switch( $opmode ) {
+    case 1: // dbonly
+      $data = $this->_db_lookup_zip($country,$postal);
+      break;
 
-      case 2: // dbfirst
-	{
-	  $data = $this->_db_lookup_zip($country,$postal);
-	  if( $data === FALSE )
-	    {
-	      $data = $this->_online_lookup_zip($country,$postal);
-	    }
-	}
-	break;
-
-      case 3: // dbfirst_cache
-	{
-	  $data = $this->_db_lookup_zip($country,$postal);
-	  if( $data === FALSE )
-	    {
-	      $data = $this->_online_lookup_zip($country,$postal);
-	      if( $data !== FALSE )
-		{
-		  $this->_store_zip($data);
-		}
-	    }
-	}
-	break;
-
-      case 4: // onlineonly
-	{
-	  $data = $this->_online_lookup_zip($country,$postal);
-	}
-	break;
+    case 2: // dbfirst
+      $data = $this->_db_lookup_zip($country,$postal);
+      if( $data === FALSE ) {
+	$data = $this->_online_lookup_zip($country,$postal);
       }
+      break;
+
+    case 3: // dbfirst_cache
+      $data = $this->_db_lookup_zip($country,$postal);
+      if( $data === FALSE ) {
+	$data = $this->_online_lookup_zip($country,$postal);
+	if( $data !== FALSE ) {
+	  $this->_store_zip($data);
+	}
+      }
+      break;
+
+    case 4: // onlineonly
+      $data = $this->_online_lookup_zip($country,$postal);
+      break;
+    }
 
     return $data;
   }
